TempoTokenApiServer

Trait TempoTokenApiServer 

pub trait TempoTokenApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required methods
    fn role_history<'life0, 'async_trait>(
        &'life0 self,
        params: PaginationParams<RoleHistoryFilters>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<RoleHistoryResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn tokens<'life0, 'async_trait>(
        &'life0 self,
        params: PaginationParams<TokensFilters>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<TokensResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn tokens_by_address<'life0, 'async_trait>(
        &'life0 self,
        params: TokensByAddressParams,
    ) -> Pin<Box<dyn Future<Output = RpcResult<TokensByAddressResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the TempoTokenApi RPC API.

Required Methods

fn role_history<'life0, 'async_trait>( &'life0 self, params: PaginationParams<RoleHistoryFilters>, ) -> Pin<Box<dyn Future<Output = RpcResult<RoleHistoryResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets paginated role change history for TIP-20 tokens on Tempo.

Tracks role grants and revocations from the RoleMembershipUpdated event for audit trails and compliance monitoring.

Uses cursor-based pagination for stable iteration through role changes.

fn tokens<'life0, 'async_trait>( &'life0 self, params: PaginationParams<TokensFilters>, ) -> Pin<Box<dyn Future<Output = RpcResult<TokensResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets paginated TIP-20 tokens on Tempo.

Uses cursor-based pagination for stable iteration through tokens.

fn tokens_by_address<'life0, 'async_trait>( &'life0 self, params: TokensByAddressParams, ) -> Pin<Box<dyn Future<Output = RpcResult<TokensByAddressResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets paginated TIP-20 tokens associated with an account address on Tempo.

Returns tokens where the account has a balance or specific roles.

Uses cursor-based pagination for stable iteration through tokens.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<EthApi: RpcNodeCore> TempoTokenApiServer for TempoToken<EthApi>